@@ -4,8 +4,8 @@
 
 ;; Author: James Ferguson <(concat "wjcferguson" at-sign "gmail.com")>
 ;; URL: https://github.com/WJCFerguson/emacs-faff-theme
-;; Package-Version: 20251229.2005
-;; Package-Revision: 234889b84663
+;; Package-Version: 20260209.2337
+;; Package-Revision: 216b52467e2f
 ;; Keywords: color theme
 
 ;; This file is not part of GNU Emacs.
@@ -238,8 +238,13 @@
  '(symbol-overlay-face-4 ((t (:background "orchid1" :foreground "black"))))
  '(symbol-overlay-face-5 ((t (:background "red1" :foreground "black"))))
  '(tab-bar ((t (:background "#aca895" :height 0.9))))
- '(tab-bar-tab-inactive ((t (:inherit (variable-pitch tab-tar)))))
+ '(tab-bar-tab-inactive ((t (:inherit (variable-pitch tab-bar)))))
  '(tab-bar-tab ((t (:inherit (tab-bar-tab-inactive) :background "cornsilk3"))))
+ '(tab-line ((t (:background "#aca895" :height 0.9))))
+ '(tab-line-tab ((t (:inherit (variable-pitch tab-line)))))
+ '(tab-line-tab-inactive ((t (:inherit (variable-pitch tab-line)))))
+ '(tab-line-tab-current ((t (:inherit (tab-line-tab-inactive) :background "cornsilk3"))))
+ '(tab-line-highlight ((t (:inherit (tab-line bold)))))
  '(term-color-green ((t (:background "green4" :foreground "green4"))))
  '(term-color-cyan ((t (:background "cyan4" :foreground "cyan4"))))
  '(term-color-magenta ((t (:background "magenta4" :foreground "magenta4"))))
